#!/usr/bin/env python3
import os

"""
Main Flask RESTful API
"""

__author__ = "@tormakris"
__copyright__ = "Copyright 2020, Birbnetes Team"
__module_name__ = "app"
__version__text__ = "1"

_POSTGRES_HOSTNAME = os.getenv("INPUT_POSTGRES_HOSTNAME", "localhost")
_POSTGRES_USERNAME = os.getenv("INPUT_POSTGRES_USERNAME", "input-service")
_POSTGRES_PASSWORD = os.getenv("INPUT_POSTGRES_PASSWORD", "input-service")
_POSTGRES_DB = os.getenv("INPUT_POSTGRES_DB", "input-service")
_POSTGRES_OPTS = os.getenv("INPUT_POSTGRES_OPTS", "")


class Config:
    PORT = int(os.environ.get("INPUT_SERVICE_PORT", 8080))
    DEBUG = os.environ.get("INPUT_SERVICE_DEBUG", "true").lower() in ["true", "yes", "1"]

    SENTRY_DSN = os.environ.get("SENTRY_DSN")
    RELEASE_ID = os.environ.get("RELEASE_ID", "test")
    RELEASEMODE = os.environ.get("INPUT_SERVICE_RELEASEMODE", "dev")

    EXCHANGE_NAME = os.getenv("INPUT_RABBITMQ_EXCHANGE", "dev")
    RABBITMQ_QUEUE = os.getenv("INPUT_RABBITMQ_QUEUE", "wave-extract")

    FLASK_PIKA_PARAMS = {
        'host': os.getenv("INPUT_RABBITMQ_HOSTNAME", "localhost"),
        'username': os.getenv("INPUT_RABBITMQ_USERNAME", "rabbitmq"),
        'password': os.getenv("INPUT_RABBITMQ_PASSWORD", "rabbitmq"),
        'port': int(os.getenv("INPUT_RABBITMQ_PORT", 5672)),
        'virtual_host': '/'
    }

    SQLALCHEMY_DATABASE_URI = f"postgresql://{_POSTGRES_USERNAME}:{_POSTGRES_PASSWORD}@{_POSTGRES_HOSTNAME}:5432/{_POSTGRES_DB}{_POSTGRES_OPTS}"

    STORAGE_HOSTNAME = os.getenv("INPUT_STORAGE_HOSTNAME", "localhost:8042")

    ENABLE_INFLUXDB = os.environ.get("INPUT_ENABLE_INFLUX", "true").lower() in ["true", "yes", "1"]
    INFLUXDB_HOST = os.getenv("INFLUX_HOST", "input-influx")
    INFLUXDB_PORT = os.getenv("INFLUX_PORT", "8086")
    INFLUXDB_USER = os.getenv("INFLUX_USERNAME", "input-service")
    INFLUXDB_PASSWORD = os.getenv("INFLUX_PASSWORD", "input-service-supersecret")
    INFLUXDB_DATABASE = os.getenv("INFLUX_DB", "input-service")
